==> structure-js-0.11.0.tgz: package/docs/api.js <==
YUI.add("yuidoc-meta", function(Y) {
   Y.YUIDoc = { meta: {
    "classes": [
        "ApplicationCacheController",
        "ApplicationCacheEvent",
        "BaseEvent",
        "BaseModel",
        "BaseObject",
        "BrowserUtil",
        "BulkLoader",
        "BulkLoaderEvent",
        "Collection",
        "ComponentFactory",
        "DOMElement",
        "DateUtil",
        "DisplayObject",
        "DisplayObjectContainer",
        "EventBroker",
        "EventDispatcher",
        "Extend",
        "ImageLoader",
        "LoaderEvent",
        "LocalStorageController",
        "LocalStorageEvent",
        "MathUtil",
        "MerchantUtil",
        "NetworkMonitor",
        "NetworkMonitorEvent",
        "NumberUtil",
        "ObjectManager",
        "Point",
        "Route",
        "Router",
        "RouterEvent",
        "Stage",
        "StringUtil",
        "TemplateFactory",
        "Timer",
        "TimerEvent",
        "Util",
        "ValidationUtil"
    ],
    "modules": [
        "StructureJS",
        "controller",
        "core",
        "event",
        "geom",
        "model",
        "util",
        "view"
    ],
    "allModules": [
        {
            "displayName": "controller",
            "name": "controller",
            "description": "The ApplicationCacheController is a static class works with the window applicationCache object."
        },
        {
            "displayName": "core",
            "name": "core",
            "description": "The {{#crossLink \"BaseObject\"}}{{/crossLink}} class is an abstract class that provides common properties and functionality for all StructureJS classes."
        },
        {
            "displayName": "event",
            "name": "event",
            "description": "The ApplicationCacheEvent ...."
        },
        {
            "displayName": "geom",
            "name": "geom",
            "description": "The Point object represents a location in a two-dimensional coordinate system, where x represents the horizontal axis and y represents the vertical axis."
        },
        {
            "displayName": "model",
            "name": "model",
            "description": "Base Model is a design pattern used to transfer data between software application subsystems.\n\n Note: If the data doesn't match the property names you can set the value manually after update super method has been called.\nAlso in the class you inherit BaseModel from you can override the update method to handle the data how you want."
        },
        {
            "displayName": "StructureJS",
            "name": "StructureJS"
        },
        {
            "displayName": "util",
            "name": "util",
            "description": "A helper class to detect OS and browsers."
        },
        {
            "displayName": "view",
            "name": "view",
            "description": "The {{#crossLink \"DOMElement\"}}{{/crossLink}} class is the base view class for all objects that can be placed into the HTML DOM."
        }
    ]
} };
});

==> structure-js-0.13.2.tgz: package/docs/api.js <==
YUI.add("yuidoc-meta", function(Y) {
   Y.YUIDoc = { meta: {
    "classes": [
        "ApplicationCacheEvent",
        "ApplicationCacheService",
        "BaseEvent",
        "BaseModel",
        "BaseObject",
        "BrowserUtil",
        "BulkLoader",
        "BulkLoaderEvent",
        "Collection",
        "ComponentFactory",
        "DOMElement",
        "DateUtil",
        "DisplayObject",
        "DisplayObjectContainer",
        "EventBroker",
        "EventDispatcher",
        "Extend",
        "ImageLoader",
        "LoaderEvent",
        "LocalStorageEvent",
        "LocalStorageService",
        "MathUtil",
        "MerchantUtil",
        "NetworkMonitor",
        "NetworkMonitorEvent",
        "NumberUtil",
        "ObjectManager",
        "Point",
        "Route",
        "Router",
        "RouterEvent",
        "Stage",
        "StringUtil",
        "TemplateFactory",
        "Timer",
        "TimerEvent",
        "Util",
        "ValidationUtil"
    ],
    "modules": [
        "StructureJS",
        "controller",
        "core",
        "event",
        "geom",
        "model",
        "util",
        "view"
    ],
    "allModules": [
        {
            "displayName": "controller",
            "name": "controller",
            "description": "The ApplicationCacheService is a static class works with the window applicationCache object."
        },
        {
            "displayName": "core",
            "name": "core",
            "description": "The {{#crossLink \"BaseObject\"}}{{/crossLink}} class is an abstract class that provides common properties and functionality for all StructureJS classes."
        },
        {
            "displayName": "event",
            "name": "event",
            "description": "The ApplicationCacheEvent ...."
        },
        {
            "displayName": "geom",
            "name": "geom",
            "description": "The Point object represents a location in a two-dimensional coordinate system, where x represents the horizontal axis and y represents the vertical axis."
        },
        {
            "displayName": "model",
            "name": "model",
            "description": "Base Model is a design pattern used to transfer data between software application subsystems.\n\n Note: If the data doesn't match the property names you can set the value manually after update super method has been called.\nAlso in the class you inherit BaseModel from you can override the update method to handle the data how you want."
        },
        {
            "displayName": "StructureJS",
            "name": "StructureJS"
        },
        {
            "displayName": "util",
            "name": "util",
            "description": "A helper class to detect OS and browsers."
        },
        {
            "displayName": "view",
            "name": "view",
            "description": "The {{#crossLink \"DOMElement\"}}{{/crossLink}} class is the base view class for all objects that can be placed into the HTML DOM."
        }
    ]
} };
});
